@@ -8,7 +8,8 @@ OPTION_CHAR =  ' '
 HOME = os.path.expanduser("~")
 GNGEO_CFG_FILE = HOME + '/.gngeo/gngeorc'
 GNGEOGUI_CFG_FILE = HOME + '/.gngeo-gui/gngeo-gui.cfg'
-buttons = ""
+P1buttons = ""
+P2buttons = ""
 BiosPath = ""
 RomrcPath = ""
 RomPath = ""
@@ -174,7 +175,7 @@ class AboutWindow(QMainWindow):
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
         self.setAttribute(Qt.WA_DeleteOnClose)
         self.label = QLabel(self)
-        AboutTxt = "<h3>Gngeo-gui 0.0.3-3</h3><p>" \
+        AboutTxt = "<h3>Gngeo-gui 0.0.4-1</h3><p>" \
                    "<img src=/opt/usr/share/icons/hicolor/64x64/apps/gngeo_gui.png /><br>" \
                    "GnGeo-gui is a Graphical User Interface for GnGeo<p> " \
                    "GnGeo emulates the NeoGeo gameconsole from SNK &#174;</p>" \
@@ -349,13 +350,20 @@ class ConfigWindow(QMainWindow):
 			ConfigFile.write("exec_path" + " " + ExecPath + "\n")
 			ConfigFile.close()
 
-	if buttons != "":
+	if P1buttons != "":
 		tot_sleutel=""
-		for sleutel in buttons:
+		for sleutel in P1buttons:
 			tot_sleutel = tot_sleutel + sleutel + ","
 		tot_sleutel = tot_sleutel[:-1]
 		self.options["p1key"] = tot_sleutel
 
+	if P2buttons != "":
+		tot_sleutel=""
+		for sleutel in P2buttons:
+			tot_sleutel = tot_sleutel + sleutel + ","
+		tot_sleutel = tot_sleutel[:-1]
+		self.options["p2key"] = tot_sleutel
+
         orgConfigFile = open(GNGEO_CFG_FILE,"r")
 	try:
 	        copyFile = open(GNGEO_CFG_FILE + ".old" ,"w")
@@ -393,193 +401,339 @@ class ConfigWindow(QMainWindow):
 class keyWindow(QDialog):
     def __init__(self, parent=None):
         super(keyWindow, self).__init__(parent)
-        self.setWindowTitle("GnGeo-gui key config")
+        self.setWindowTitle("GnGeo-gui button config")
 	# order : A,B,C,D,START,COIN,UP,DOWN,LEFT,RIGHT
-	if buttons == "":
+	if P1buttons == "":
         	self.options = parse_config(self,GNGEO_CFG_FILE)
 		self.P1Keys=self.options["p1key"].split(",")
 	else:
-		self.P1Keys = buttons
-	Akey=self.P1Keys[0]
-	Bkey=self.P1Keys[1]
-	Ckey=self.P1Keys[2]
-	Dkey=self.P1Keys[3]
-	Startkey=self.P1Keys[4]
-	Coinkey=self.P1Keys[5]
-	Upkey=self.P1Keys[6]
-	Downkey=self.P1Keys[7]
-	Leftkey=self.P1Keys[8]
-	Rightkey=self.P1Keys[9]
+		self.P1Keys = P1buttons
+	if P2buttons == "":
+        	self.options = parse_config(self,GNGEO_CFG_FILE)
+		self.P2Keys=self.options["p2key"].split(",")
+	else:
+		self.P2Keys = P2buttons
+	# P1 keys
+	P1Akey=self.P1Keys[0]
+	P1Bkey=self.P1Keys[1]
+	P1Ckey=self.P1Keys[2]
+	P1Dkey=self.P1Keys[3]
+	P1Startkey=self.P1Keys[4]
+	P1Coinkey=self.P1Keys[5]
+	P1Upkey=self.P1Keys[6]
+	P1Downkey=self.P1Keys[7]
+	P1Leftkey=self.P1Keys[8]
+	P1Rightkey=self.P1Keys[9]
+	# P2 keys
+	P2Akey=self.P2Keys[0]
+	P2Bkey=self.P2Keys[1]
+	P2Ckey=self.P2Keys[2]
+	P2Dkey=self.P2Keys[3]
+	P2Startkey=self.P2Keys[4]
+	P2Coinkey=self.P2Keys[5]
+	P2Upkey=self.P2Keys[6]
+	P2Downkey=self.P2Keys[7]
+	P2Leftkey=self.P2Keys[8]
+	P2Rightkey=self.P2Keys[9]
+	# Layout
 	area = QScrollArea(self)
 	lay = QVBoxLayout(self)
 	lay.addWidget(area)
 	wg = QWidget()
 	area.setWidget(wg)
-	wg.setMinimumSize(600,900);
+	wg.resize(750,900);
 	grid = QGridLayout(wg)
 	wg.show()
 	area.show()
 	grid.setColumnStretch(2, 20)
         font = QFont()
         font.setPointSize(24)
-	# A-button
-	self.AkeySpinBox = QDoubleSpinBox()
-	self.AkeySpinBox.setRange(0, 307)
-	self.AkeySpinBox.setValue(float(Akey))
-	self.AkeySpinBox.setMinimumSize(150,60)
-	self.AkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("A"), 1, 0 )
-	grid.addWidget(self.AkeySpinBox, 1, 1)
-	self.AButton = MyKeyPressed("pick A key",self)
-	grid.addWidget(self.AButton, 1, 2)
-	# B-button
-	self.BkeySpinBox = QDoubleSpinBox()
-	self.BkeySpinBox.setRange(1, 307)
-	self.BkeySpinBox.setValue(float(Bkey))
-	self.BkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("B"), 2, 0)
-	grid.addWidget(self.BkeySpinBox, 2, 1)
-	self.BButton = MyKeyPressed("pick B key",self)
-	grid.addWidget(self.BButton, 2, 2)
-	# C-button
-	self.CkeySpinBox = QDoubleSpinBox()
-	self.CkeySpinBox.setRange(1, 307)
-	self.CkeySpinBox.setValue(float(Ckey))
-	self.CkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("C"), 3, 0)
-	grid.addWidget(self.CkeySpinBox, 3, 1)
-	self.CButton = MyKeyPressed("pick C key",self)
-	grid.addWidget(self.CButton, 3, 2)
-	# D-button
-	self.DkeySpinBox = QDoubleSpinBox()
-	self.DkeySpinBox.setRange(0, 307)
-	self.DkeySpinBox.setValue(float(Dkey))
-	self.DkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("D"), 4, 0)
-	grid.addWidget(self.DkeySpinBox, 4, 1)
-	self.DButton = MyKeyPressed("pick D key",self)
-	grid.addWidget(self.DButton, 4, 2)
-	# Start-button
-	self.StartkeySpinBox = QDoubleSpinBox()
-	self.StartkeySpinBox.setRange(0, 307)
-	self.StartkeySpinBox.setValue(float(Startkey))
-	self.StartkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("START"), 5, 0)
-	grid.addWidget(self.StartkeySpinBox, 5, 1)
-	self.StartButton = MyKeyPressed("pick START key",self)
-	grid.addWidget(self.StartButton, 5, 2)
-	# Coin-button
-	self.CoinkeySpinBox = QDoubleSpinBox()
-	self.CoinkeySpinBox.setRange(0, 307)
-	self.CoinkeySpinBox.setValue(float(Coinkey))
-	self.CoinkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("COIN"), 6, 0)
-	grid.addWidget(self.CoinkeySpinBox, 6, 1)
-	self.CoinButton = MyKeyPressed("pick COIN key",self)
-	grid.addWidget(self.CoinButton, 6, 2)
-	# Up-key
-	self.UpkeySpinBox = QDoubleSpinBox()
-	self.UpkeySpinBox.setRange(0, 307)
-	self.UpkeySpinBox.setValue(float(Upkey))
-	self.UpkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("UP"), 7, 0)
-	grid.addWidget(self.UpkeySpinBox, 7, 1)
-	self.UpButton = MyKeyPressed("pick UP key",self)
-	grid.addWidget(self.UpButton, 7, 2)
-	# Down-key
-	self.DownkeySpinBox = QDoubleSpinBox()
-	self.DownkeySpinBox.setRange(0, 307)
-	self.DownkeySpinBox.setValue(float(Downkey))
-	self.DownkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("DOWN"), 8, 0)
-	grid.addWidget(self.DownkeySpinBox, 8, 1)
-	self.DownButton = MyKeyPressed("pick DOWN key",self)
-	grid.addWidget(self.DownButton, 8, 2)
-	# Left-key
-	self.LeftkeySpinBox = QDoubleSpinBox()
-	self.LeftkeySpinBox.setRange(0, 307)
-	self.LeftkeySpinBox.setValue(float(Leftkey))
-	self.LeftkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("LEFT"), 9, 0)
-	grid.addWidget(self.LeftkeySpinBox, 9, 1)
-	self.LeftButton = MyKeyPressed("pick LEFT key",self)
-	grid.addWidget(self.LeftButton, 9, 2)
-	# Right-key
-	self.RightkeySpinBox = QDoubleSpinBox()
-	self.RightkeySpinBox.setRange(0, 307)
-	self.RightkeySpinBox.setValue(float(Rightkey))
-	self.RightkeySpinBox.setDecimals(0)
-	grid.addWidget(QLabel("RIGHT"), 10, 0)
-	grid.addWidget(self.RightkeySpinBox, 10, 1)
-	self.RightButton = MyKeyPressed("pick RIGHT key",self)
-	grid.addWidget(self.RightButton, 10, 2)
+	minKeyValue=1
+	maxKeyValue=307
+	grid.addWidget(QLabel("<center>PLAYER 1</center>"), 1, 1)
+	grid.addWidget(QLabel("<center>[pick]</center>"), 1, 2)
+	grid.addWidget(QLabel("<center>PLAYER 2</center>"), 1, 3)
+	grid.addWidget(QLabel("<center>[pick]</center>"), 1, 4)
+	# Add button list
+        cntr=2
+	for pButton in ['A','B','C','D','START','COIN','UP','DOWN','LEFT','RIGHT']:
+		grid.addWidget(QLabel(pButton), cntr, 0)
+		cntr=cntr+1
+	# A-button P2
+	self.P1AkeySpinBox = QDoubleSpinBox()
+	self.P1AkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1AkeySpinBox.setValue(float(P1Akey))
+	self.P1AkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1AkeySpinBox, 2, 1)
+	self.P1AButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1AButton, 2, 2)
+	# A-button P2
+	self.P2AkeySpinBox = QDoubleSpinBox()
+	self.P2AkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2AkeySpinBox.setValue(float(P2Akey))
+	self.P2AkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2AkeySpinBox, 2, 3)
+	self.P2AButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2AButton, 2, 4)
+	# B-button P1
+	self.P1BkeySpinBox = QDoubleSpinBox()
+	self.P1BkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1BkeySpinBox.setValue(float(P1Bkey))
+	self.P1BkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1BkeySpinBox, 3, 1)
+	self.P1BButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1BButton, 3, 2)
+	# B-button P2
+	self.P2BkeySpinBox = QDoubleSpinBox()
+	self.P2BkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2BkeySpinBox.setValue(float(P2Bkey))
+	self.P2BkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2BkeySpinBox, 3, 3)
+	self.P2BButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2BButton, 3, 4)
+	# C-button P1
+	self.P1CkeySpinBox = QDoubleSpinBox()
+	self.P1CkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1CkeySpinBox.setValue(float(P1Ckey))
+	self.P1CkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1CkeySpinBox, 4, 1)
+	self.P1CButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1CButton, 4, 2)
+	# C-button P2
+	self.P2CkeySpinBox = QDoubleSpinBox()
+	self.P2CkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2CkeySpinBox.setValue(float(P2Ckey))
+	self.P2CkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2CkeySpinBox, 4, 3)
+	self.P2CButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2CButton, 4, 4)
+	# D-button P1
+	self.P1DkeySpinBox = QDoubleSpinBox()
+	self.P1DkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1DkeySpinBox.setValue(float(P1Dkey))
+	self.P1DkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1DkeySpinBox, 5, 1)
+	self.P1DButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1DButton, 5, 2)
+	# D-button P2
+	self.P2DkeySpinBox = QDoubleSpinBox()
+	self.P2DkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2DkeySpinBox.setValue(float(P2Dkey))
+	self.P2DkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2DkeySpinBox, 5, 3)
+	self.P2DButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2DButton, 5, 4)
+	# Start-button P1
+	self.P1StartkeySpinBox = QDoubleSpinBox()
+	self.P1StartkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1StartkeySpinBox.setValue(float(P1Startkey))
+	self.P1StartkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1StartkeySpinBox, 6, 1)
+	self.P1StartButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1StartButton, 6, 2)
+	# Start-button P2
+	self.P2StartkeySpinBox = QDoubleSpinBox()
+	self.P2StartkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2StartkeySpinBox.setValue(float(P2Startkey))
+	self.P2StartkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2StartkeySpinBox, 6, 3)
+	self.P2StartButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2StartButton, 6, 4)
+	# Coin-button P1
+	self.P1CoinkeySpinBox = QDoubleSpinBox()
+	self.P1CoinkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1CoinkeySpinBox.setValue(float(P1Coinkey))
+	self.P1CoinkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1CoinkeySpinBox, 7, 1)
+	self.P1CoinButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1CoinButton, 7, 2)
+	# Coin-button P2
+	self.P2CoinkeySpinBox = QDoubleSpinBox()
+	self.P2CoinkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2CoinkeySpinBox.setValue(float(P2Coinkey))
+	self.P2CoinkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2CoinkeySpinBox, 7, 3)
+	self.P2CoinButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2CoinButton, 7, 4)
+	# Up-key P1
+	self.P1UpkeySpinBox = QDoubleSpinBox()
+	self.P1UpkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1UpkeySpinBox.setValue(float(P1Upkey))
+	self.P1UpkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1UpkeySpinBox, 8, 1)
+	self.P1UpButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1UpButton, 8, 2)
+	# Up-key P2
+	self.P2UpkeySpinBox = QDoubleSpinBox()
+	self.P2UpkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2UpkeySpinBox.setValue(float(P2Upkey))
+	self.P2UpkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2UpkeySpinBox, 8, 3)
+	self.P2UpButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2UpButton, 8, 4)
+	# Down-key P1
+	self.P1DownkeySpinBox = QDoubleSpinBox()
+	self.P1DownkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1DownkeySpinBox.setValue(float(P1Downkey))
+	self.P1DownkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1DownkeySpinBox, 9, 1)
+	self.P1DownButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1DownButton, 9, 2)
+	# Down-key P2
+	self.P2DownkeySpinBox = QDoubleSpinBox()
+	self.P2DownkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2DownkeySpinBox.setValue(float(P2Downkey))
+	self.P2DownkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2DownkeySpinBox, 9, 3)
+	self.P2DownButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2DownButton, 9, 4)
+	# Left-key P1
+	self.P1LeftkeySpinBox = QDoubleSpinBox()
+	self.P1LeftkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1LeftkeySpinBox.setValue(float(P1Leftkey))
+	self.P1LeftkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1LeftkeySpinBox, 10, 1)
+	self.P1LeftButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1LeftButton, 10, 2)
+	# Left-key P2
+	self.P2LeftkeySpinBox = QDoubleSpinBox()
+	self.P2LeftkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2LeftkeySpinBox.setValue(float(P2Leftkey))
+	self.P2LeftkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2LeftkeySpinBox, 10, 3)
+	self.P2LeftButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2LeftButton, 10, 4)
+	# Right-key P1
+	self.P1RightkeySpinBox = QDoubleSpinBox()
+	self.P1RightkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P1RightkeySpinBox.setValue(float(P1Rightkey))
+	self.P1RightkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P1RightkeySpinBox, 11, 1)
+	self.P1RightButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P1RightButton, 11, 2)
+	# Right-key P1
+	self.P2RightkeySpinBox = QDoubleSpinBox()
+	self.P2RightkeySpinBox.setRange(minKeyValue, maxKeyValue)
+	self.P2RightkeySpinBox.setValue(float(P2Rightkey))
+	self.P2RightkeySpinBox.setDecimals(0)
+	grid.addWidget(self.P2RightkeySpinBox, 11, 3)
+	self.P2RightButton = MyKeyPressed("key",self)
+	grid.addWidget(self.P2RightButton, 11, 4)
 
 	self.setLayout(grid)
-	self.connect(self.AkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.BkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.CkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.DkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.StartkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.CoinkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.UpkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.DownkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.LeftkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-	self.connect(self.RightkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
-        self.connect(self.RightButton, SIGNAL("keyPressed"),self.updateRight)
-        self.connect(self.LeftButton, SIGNAL("keyPressed"),self.updateLeft)
-        self.connect(self.DownButton, SIGNAL("keyPressed"),self.updateDown)
-        self.connect(self.UpButton, SIGNAL("keyPressed"),self.updateUp)
-        self.connect(self.CoinButton, SIGNAL("keyPressed"),self.updateCoin)
-        self.connect(self.StartButton, SIGNAL("keyPressed"),self.updateStart)
-        self.connect(self.AButton, SIGNAL("keyPressed"),self.updateA)
-        self.connect(self.BButton, SIGNAL("keyPressed"),self.updateB)
-        self.connect(self.CButton, SIGNAL("keyPressed"),self.updateC)
-        self.connect(self.DButton, SIGNAL("keyPressed"),self.updateD)
+	# P1
+	self.connect(self.P1AkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1BkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1CkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1DkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1StartkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1CoinkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1UpkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1DownkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1LeftkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P1RightkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1RightButton, SIGNAL("keyPressed"),self.P1updateRight)
+        self.connect(self.P1LeftButton, SIGNAL("keyPressed"),self.P1updateLeft)
+        self.connect(self.P1DownButton, SIGNAL("keyPressed"),self.P1updateDown)
+        self.connect(self.P1UpButton, SIGNAL("keyPressed"),self.P1updateUp)
+        self.connect(self.P1CoinButton, SIGNAL("keyPressed"),self.P1updateCoin)
+        self.connect(self.P1StartButton, SIGNAL("keyPressed"),self.P1updateStart)
+        self.connect(self.P1AButton, SIGNAL("keyPressed"),self.P1updateA)
+        self.connect(self.P1BButton, SIGNAL("keyPressed"),self.P1updateB)
+        self.connect(self.P1CButton, SIGNAL("keyPressed"),self.P1updateC)
+        self.connect(self.P1DButton, SIGNAL("keyPressed"),self.P1updateD)
+	# P2
+	self.connect(self.P2AkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2BkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2CkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2DkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2StartkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2CoinkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2UpkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2DownkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2LeftkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+	self.connect(self.P2RightkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P2RightButton, SIGNAL("keyPressed"),self.P2updateRight)
+        self.connect(self.P2LeftButton, SIGNAL("keyPressed"),self.P2updateLeft)
+        self.connect(self.P2DownButton, SIGNAL("keyPressed"),self.P2updateDown)
+        self.connect(self.P2UpButton, SIGNAL("keyPressed"),self.P2updateUp)
+        self.connect(self.P2CoinButton, SIGNAL("keyPressed"),self.P2updateCoin)
+        self.connect(self.P2StartButton, SIGNAL("keyPressed"),self.P2updateStart)
+        self.connect(self.P2AButton, SIGNAL("keyPressed"),self.P2updateA)
+        self.connect(self.P2BButton, SIGNAL("keyPressed"),self.P2updateB)
+        self.connect(self.P2CButton, SIGNAL("keyPressed"),self.P2updateC)
+        self.connect(self.P2DButton, SIGNAL("keyPressed"),self.P2updateD)
 
-    def updateRight(self):
-	self.RightkeySpinBox.setValue(float(AsciiVal))
-		
-    def updateLeft(self):
-	self.LeftkeySpinBox.setValue(float(AsciiVal))
-
-    def updateUp(self):
-	self.UpkeySpinBox.setValue(float(AsciiVal))
-
-    def updateDown(self):
-	self.DownkeySpinBox.setValue(float(AsciiVal))
-
-    def updateStart(self):
-	self.StartkeySpinBox.setValue(float(AsciiVal))
-
-    def updateCoin(self):
-	self.CoinkeySpinBox.setValue(float(AsciiVal))
-
-    def updateA(self):
-	self.AkeySpinBox.setValue(float(AsciiVal))
-
-    def updateB(self):
-	self.BkeySpinBox.setValue(float(AsciiVal))
-
-    def updateC(self):
-	self.CkeySpinBox.setValue(float(AsciiVal))
-
-    def updateD(self):
-	self.DkeySpinBox.setValue(float(AsciiVal))
+	# P1
+    def P1updateRight(self):
+	self.P1RightkeySpinBox.setValue(float(AsciiVal))
+    def P1updateLeft(self):
+	self.P1LeftkeySpinBox.setValue(float(AsciiVal))
+    def P1updateUp(self):
+	self.P1UpkeySpinBox.setValue(float(AsciiVal))
+    def P1updateDown(self):
+	self.P1DownkeySpinBox.setValue(float(AsciiVal))
+    def P1updateStart(self):
+	self.P1StartkeySpinBox.setValue(float(AsciiVal))
+    def P1updateCoin(self):
+	self.P1CoinkeySpinBox.setValue(float(AsciiVal))
+    def P1updateA(self):
+	self.P1AkeySpinBox.setValue(float(AsciiVal))
+    def P1updateB(self):
+	self.P1BkeySpinBox.setValue(float(AsciiVal))
+    def P1updateC(self):
+	self.P1CkeySpinBox.setValue(float(AsciiVal))
+    def P1updateD(self):
+	self.P1DkeySpinBox.setValue(float(AsciiVal))
+	# P2
+    def P2updateRight(self):
+	self.P2RightkeySpinBox.setValue(float(AsciiVal))
+    def P2updateLeft(self):
+	self.P2LeftkeySpinBox.setValue(float(AsciiVal))
+    def P2updateUp(self):
+	self.P2UpkeySpinBox.setValue(float(AsciiVal))
+    def P2updateDown(self):
+	self.P2DownkeySpinBox.setValue(float(AsciiVal))
+    def P2updateStart(self):
+	self.P2StartkeySpinBox.setValue(float(AsciiVal))
+    def P2updateCoin(self):
+	self.P2CoinkeySpinBox.setValue(float(AsciiVal))
+    def P2updateA(self):
+	self.P2AkeySpinBox.setValue(float(AsciiVal))
+    def P2updateB(self):
+	self.P2BkeySpinBox.setValue(float(AsciiVal))
+    def P2updateC(self):
+	self.P2CkeySpinBox.setValue(float(AsciiVal))
+    def P2updateD(self):
+	self.P2DkeySpinBox.setValue(float(AsciiVal))
 
     def change_value(self,event):
-	self.P1Keys[0] = "%.0f" % self.AkeySpinBox.value()
-	self.P1Keys[1] = "%.0f" % self.BkeySpinBox.value()
-	self.P1Keys[2] = "%.0f" % self.CkeySpinBox.value()
-	self.P1Keys[3] = "%.0f" % self.DkeySpinBox.value()
-	self.P1Keys[4] = "%.0f" % self.StartkeySpinBox.value()
-	self.P1Keys[5] = "%.0f" % self.CoinkeySpinBox.value()
-	self.P1Keys[6] = "%.0f" % self.UpkeySpinBox.value()
-	self.P1Keys[7] = "%.0f" % self.DownkeySpinBox.value()
-	self.P1Keys[8] = "%.0f" % self.LeftkeySpinBox.value()
-	self.P1Keys[9] = "%.0f" % self.RightkeySpinBox.value()
-	global buttons
-	buttons = self.P1Keys
-
+	# P1
+	self.P1Keys[0] = "%.0f" % self.P1AkeySpinBox.value()
+	self.P1Keys[1] = "%.0f" % self.P1BkeySpinBox.value()
+	self.P1Keys[2] = "%.0f" % self.P1CkeySpinBox.value()
+	self.P1Keys[3] = "%.0f" % self.P1DkeySpinBox.value()
+	self.P1Keys[4] = "%.0f" % self.P1StartkeySpinBox.value()
+	self.P1Keys[5] = "%.0f" % self.P1CoinkeySpinBox.value()
+	self.P1Keys[6] = "%.0f" % self.P1UpkeySpinBox.value()
+	self.P1Keys[7] = "%.0f" % self.P1DownkeySpinBox.value()
+	self.P1Keys[8] = "%.0f" % self.P1LeftkeySpinBox.value()
+	self.P1Keys[9] = "%.0f" % self.P1RightkeySpinBox.value()
+	# P2
+	self.P2Keys[0] = "%.0f" % self.P2AkeySpinBox.value()
+	self.P2Keys[1] = "%.0f" % self.P2BkeySpinBox.value()
+	self.P2Keys[2] = "%.0f" % self.P2CkeySpinBox.value()
+	self.P2Keys[3] = "%.0f" % self.P2DkeySpinBox.value()
+	self.P2Keys[4] = "%.0f" % self.P2StartkeySpinBox.value()
+	self.P2Keys[5] = "%.0f" % self.P2CoinkeySpinBox.value()
+	self.P2Keys[6] = "%.0f" % self.P2UpkeySpinBox.value()
+	self.P2Keys[7] = "%.0f" % self.P2DownkeySpinBox.value()
+	self.P2Keys[8] = "%.0f" % self.P2LeftkeySpinBox.value()
+	self.P2Keys[9] = "%.0f" % self.P2RightkeySpinBox.value()
+	global P1buttons
+	global P2buttons
+	P1buttons = self.P1Keys
+	P2buttons = self.P2Keys
 
 class MyKeyPressed(QPushButton):
     def __init__(self, *args):
@@ -588,7 +742,6 @@ class MyKeyPressed(QPushButton):
     def event(self, event):
         if (event.type()==QEvent.KeyPress):
             # we have to get the SDL keysym
-            #print event.key()
 	    global AsciiVal
             if (event.key() < 256):
                 AsciiVal = ord(str.lower(chr(event.key())))
@@ -620,7 +773,6 @@ class MyKeyPressed(QPushButton):
                 # R-Alt
                 AsciiVal = 307;
             self.emit(SIGNAL("keyPressed"))
-            #return True
 
         return QPushButton.event(self, event)
 
